@@ -11,7 +11,7 @@ use SQL::DB::Row;
 use SQL::DB::Cursor;
 
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 our @EXPORT_OK = @SQL::DB::Schema::EXPORT_OK;
 foreach (@EXPORT_OK) {
@@ -46,6 +46,9 @@ sub new {
     if (!eval {$self->table('sqldb');1;}) {
         $self->associate_table('sqldb');
     }
+
+    # Make sure that SQL::DB::Schema::Table->ref_by works
+    map { $_->ref }  map { $_->columns } $self->tables;
     return $self;
 }
 
@@ -640,50 +643,49 @@ sub seq {
 
 sub insert {
     my $self = shift;
-    foreach my $obj (@_) {
-        unless(ref($obj) and $obj->can('q_update')) {
-            croak "Not an insertable object: $obj";
-        }
-        my ($arows, @inserts) = $obj->q_insert; # reference hand-holding
-        foreach (@inserts) {
-            $self->do(@$_);
-        }
+    my $obj  = shift || croak 'insert($obj)';
+
+    unless(ref($obj) and $obj->can('q_insert')) {
+        croak "Not an insert object: $obj";
     }
-    return 1;
+
+    my ($arows, @insert) = $obj->q_insert; # reference hand-holding
+    if (!@insert) {
+        croak "No insert for object. Missing PRIMARY KEY?";
+    }
+    return $self->do(@insert);
 }
 
 
 sub update {
     my $self = shift;
-    foreach my $obj (@_) {
-        unless(ref($obj) and $obj->can('q_update')) {
-            croak "Not an updatable object: $obj";
-        }
-        my ($arows, @updates) = $obj->q_update; # reference hand-holding
-        if (!@updates) {
-            carp "No update for object. Missing PRIMARY KEY?";
-            next;
-        }
-        foreach (@updates) {
-            $self->do(@$_);
-        }
+    my $obj  = shift || croak 'update($obj)';
+
+    unless(ref($obj) and $obj->can('q_update')) {
+        croak "Not an updatable object: $obj";
     }
-    return 1;
+
+    my ($arows, @update) = $obj->q_update; # reference hand-holding
+    if (!@update) {
+        croak "No update for object. Missing PRIMARY KEY?";
+    }
+    return $self->do(@update);
 }
 
 
 sub delete {
     my $self = shift;
-    foreach my $obj (@_) {
-        unless(ref($obj) and $obj->can('q_update')) {
-            croak "Not a deletable object: $obj";
-        }
-        my ($arows, @deletes) = $obj->q_delete; # reference hand-holding
-        foreach (@deletes) {
-            $self->do(@$_);
-        }
+    my $obj  = shift || croak 'delete($obj)';
+
+    unless(ref($obj) and $obj->can('q_delete')) {
+        croak "Not an delete object: $obj";
     }
-    return 1;
+
+    my ($arows, @delete) = $obj->q_delete; # reference hand-holding
+    if (!@delete) {
+        croak "No delete for object. Missing PRIMARY KEY?";
+    }
+    return $self->do(@delete);
 }
 
 
@@ -744,7 +746,7 @@ SQL::DB - Perl interface to SQL Databases
 
 =head1 VERSION
 
-0.17. Development release.
+0.18. Development release.
 
 =head1 SYNOPSIS
 
